# Impysonator
[![Build Status](https://travis-ci.org/guidiego/impysonator.svg?branch=master)](https://travis-ci.org/guidiego/impysonator) [![Coverage Status](https://coveralls.io/repos/github/guidiego/impysonator/badge.svg?branch=master)](https://coveralls.io/github/guidiego/impysonator?branch=master) [![Code Health](https://landscape.io/github/guidiego/impysonator/master/landscape.svg?style=flat)](https://landscape.io/github/guidiego/impysonator/master)

Um simples script em python para achar possiveis frase não impessoais em seus artigos :rocket:

## Como instalar/usar

Você precisa ter o python `3.6` na sua maquina, após isso:  

`pip install impysonator`  

`impysonator myfolder/or/myfile`

 [![gif explicativo](http://g.recordit.co/g9kyZheOXO.gif)
